logdomain

package
v0.0.0-...-b175514 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jun 29, 2026 License: AGPL-3.0 Imports: 0 Imported by: 0

Documentation

Overview

Package logdomain provides constants to identify different parts of the application.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type ID

type ID uint8

ID identifies a part of the application that wants to write messages to the log.

const (
	Collect ID = iota
	Database
	DBPool
	Monitor
	Web
	Discover
	Client
)

func All

func All() []ID

All returns a slice of all valid IDs.

Jump to